..
    Copyright (C) 2019 Esteban J. G. Gabancho.

    Flask-SSO-SAML is free software; you can redistribute it and/or modify
    it under the terms of the MIT License; see LICENSE file for more details.

================
 Flask-SSO-SAML
================

.. image:: https://img.shields.io/travis/egabancho/flask-sso-saml.svg
        :target: https://travis-ci.org/egabancho/flask-sso-saml

.. image:: https://img.shields.io/coveralls/egabancho/flask-sso-saml.svg
        :target: https://coveralls.io/r/egabancho/flask-sso-saml

.. image:: https://img.shields.io/github/tag/egabancho/flask-sso-saml.svg
        :target: https://github.com/egabancho/flask-sso-saml/releases

.. image:: https://img.shields.io/pypi/dm/flask-sso-saml.svg
        :target: https://pypi.python.org/pypi/flask-sso-saml

.. image:: https://img.shields.io/github/license/egabancho/flask-sso-saml.svg
        :target: https://github.com/egabancho/flask-sso-saml/blob/master/LICENSE

Flask extension that provides SSO SAML integration.


Features:

- Customizable endpoints.
- Several Identity Providers under the same application.
- Customizable handlers to allow decide what happens on each type of request.

Further documentation is available on
https://flask-sso-saml.readthedocs.io/
